# frozen_string_literal: true

require "uri"
require "json"

require_relative "dingding-notifier/util/http_client"

require_relative "dingding-notifier/payload_middleware"
require_relative "dingding-notifier/config"

require 'pry-byebug'

module Dingding
  class Notifier
    attr_reader :webhook_url, :client, :atMobiles, :atUserIds, :isAtAll, :middleware_name

    def initialize(options={})
      @webhook_url =  options.delete(:webhook_url)
      @client = config.http_client
      @atMobiles = options.delete(:atMobiles) || []
      @atUserIds = options.delete(:atUserIds) || []
      @isAtAll =  options.delete(:isAtAll) || false
      @middleware_name = config.middleware(options.delete(:middleware))
      if @middleware_name.is_a?(Array)
        @middleware_name = @middleware_name.first
      end
      middleware.set (@middleware_name)
    end

    def config
      @_config ||= Config.new
    end

    def call message, options={}
      options[:format_text] ||= {}
      options[:format_text][:text] = message.to_json
      post options
    end
    
    def post payload={}
      payload = {middleware_name.to_sym => payload} unless payload.key?(middleware_name)
      payload.merge!({atMobiles: atMobiles, atUserIds: atUserIds,isAtAll: isAtAll})
      client.post webhook_url, middleware.call(payload).to_json
    end

    private

      def middleware
        @middleware ||= PayloadMiddleware::Stack.new(self)
      end
  end
end
