# frozen_string_literal: true

require 'faraday'
require 'faraday_middleware'
require 'json'
require 'uri'

module Dingding
  class Notifier
    class APIError < StandardError
      attr_reader :response

      def initialize(response)
        @response = response
      end

      def message
        <<-MSG
The slack API returned an error: #{@response.body} (HTTP Code #{@response.code})
Check the "Handling Errors" section on https://api.slack.com/incoming-webhooks for more information
MSG
      end
    end

    module Util
      class HTTPClient
        class << self
          def post uri, params
            HTTPClient.new(uri, params).call
          end
        end

        attr_reader :uri, :params

        def initialize uri, params
          @uri          = uri
          @params       = params
        end

        # rubocop:disable Layout/IndentHeredoc
        def call
          response = Faraday.post(uri, params,{"Content-Type" => "application/json"})
          # http_obj.request(request_obj).tap do |response|
          #   unless response.is_a?(Net::HTTPSuccess)
          #     raise Dingding::Notifier::APIError.new(response)
          #   end
          # end
        end
      end
    end
  end
end
